@@ -132,7 +132,7 @@ class InstaLog:
         date_time = datetime.datetime.now(datetime.timezone.utc)
         return date_time.strftime("%d/%b/%Y %H:%M:%S")
 
-    def exc_info_from_error(error):
+    def exc_info_from_error(self, error):
         if isinstance(error, tuple) and len(error) == 3:
             exc_type, exc_value, tb = error
         elif isinstance(error, BaseException):
