@@ -9,8 +9,8 @@ def create_app(test_config=None):
     app = Flask(__name__, instance_relative_config=True)
     app.config.from_mapping(
         SECRET_KEY='dev',
-        INSTALOG_API_SECRET_KEY='84e74a5b-1235-4da5-85ad-b46fa7888543',
-        INSTALOG_API_KEY='ad8459f8-300c-4b56-a3ec-67552b09777e',
+        INSTALOG_API_SECRET_KEY='b1a4be7f-84b2-44e1-94ba-d4c5a030d20b',
+        INSTALOG_API_KEY='c5cd09f9-17e4-4fe4-ba8f-53593352b1da',
         INSTALOG_META_DATA={
             "environment": "staging",
             "service_name": "test_app",
